%define module	nose

Summary:	Unittest-based testing framework for Python
Name:		python-%{module}
Version:	1.3.7
Release:	%mkrel 16
License:	LGPLv2+
Group:		Development/Python
Url:		https://readthedocs.org/docs/nose/
Source0:	https://pypi.io/packages/source/n/nose/%{module}-%{version}.tar.gz
# Make compatible with coverage 4.1
# https://github.com/nose-devs/nose/pull/1004
Patch0:         python-nose-coverage4.patch
# Fix python 3.5 compat
# https://github.com/nose-devs/nose/pull/983
Patch1:         python-nose-py35.patch
# Fix UnicodeDecodeError with captured output
# https://github.com/nose-devs/nose/pull/988
Patch2:         python-nose-unicode.patch
# Allow docutils to read utf-8 source
Patch3:         python-nose-readunicode.patch
# Fix Python 3.6 compatibility
# Python now returns ModuleNotFoundError instead of the previous ImportError
# https://github.com/nose-devs/nose/pull/1029
Patch4:         python-nose-py36.patch
# Remove a SyntaxWarning (other projects may treat it as error)
Patch5:         python-nose-py38.patch
# Remove use_2to3 from setuptools.setup() call
# We call the command line tool in %%prep instead
# https://fedoraproject.org/wiki/Changes/Setuptools_58+
Patch6:         python-nose-no-use_2to3.patch
# Import unittest.TextTestResult instead of removed unittest._TextTestResult
# Use ConfigParser.read_file() instead of .readfp()
# Adapt test_xunit to tracebacks/exceptions with ^^^^^^^^ lines
# Migrate from removed inspect.getargspec() to inspect.getfullargspec()
Patch7:         python-nose-py311.patch

BuildArch:	noarch
BuildRequires:	dos2unix

%description
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

These features, and many more, are customizable through the use of plugins.
Plugins included with nose provide support for doctest, code coverage and
profiling, flexible attribute-based test selection, output capture and more.

%package -n python3-%{module}
Summary:	Discovery-based unittest extension for Python 3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(coverage) >= 3.4-1
BuildRequires:	python3dist(setuptools)
%{?python_provide:%python_provide python3-%{module}}
Requires:	python3dist(setuptools)
Obsoletes:	python2-nose < 1.3.7-10

%description -n python3-%{module}
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

%prep
%setup -q -n %{module}-%{version}
%autopatch -p1

# drop bundled egg-info
rm -rf *.egg-info/

dos2unix examples/attrib_plugin.py

%build
2to3 %{?_smp_mflags} --write --nobackups --no-diffs .
2to3 %{?_smp_mflags} --write --nobackups --no-diffs -d $(find -name '*.rst')
%py3_build

%install
%py3_install -- --install-data=%{_datadir}
# (ovitters) python-arpy expects nodetests-3 to exist
ln -sf nosetests-%{python3_version} %{buildroot}%{_bindir}/nosetests-3

%check
# Various selftests fail on our build system; skip them for now using "-e"
%{__python3} setup.py build_tests
%{__python3} selftest.py
# -e test_multiprocessing -e test_coverage_plugin

%files -n python3-%{module}
%doc AUTHORS CHANGELOG lgpl.txt NEWS README.txt
%{_bindir}/nosetests
%{_bindir}/nosetests-3
%{_bindir}/nosetests-%{python3_version}
%{_mandir}/man1/nosetests.1*
%{python3_sitelib}/nose*


%changelog
* Wed Mar 23 2022 umeabot <umeabot> 1.3.7-16.mga9
+ Revision: 1822113
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 1.3.7-15.mga9
+ Revision: 1771891
- sync with Fedora where appropriate
- rebuild for python3.10

* Sun Mar 14 2021 wally <wally> 1.3.7-14.mga9
+ Revision: 1702582
- rebuild for python 3.9

* Sat Apr 11 2020 ovitters <ovitters> 1.3.7-13.mga8
+ Revision: 1566393
- symlink binary to nosetests-3 to fix python-arpy build (matches Fedora)

* Sun Feb 16 2020 umeabot <umeabot> 1.3.7-12.mga8
+ Revision: 1530606
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 1.3.7-11.mga8
+ Revision: 1437154
- rebuild with new python-rpm-macros
- use python_provide

* Tue Sep 03 2019 wally <wally> 1.3.7-10.mga8
+ Revision: 1436784
- sync patches with Fedora
- rebuild for python3.8
- drop python2 support

* Sat Jan 05 2019 wally <wally> 1.3.7-9.mga7
+ Revision: 1349263
- rebuild for python3.7

* Thu Sep 20 2018 umeabot <umeabot> 1.3.7-8.mga7
+ Revision: 1289483
- Mageia 7 Mass Rebuild

* Mon Feb 19 2018 kekepower <kekepower> 1.3.7-7.mga7
+ Revision: 1203261
- Remove docs package
- Renamed python-nose to python2-nose
- Obsolete old named package

* Fri Sep 15 2017 tv <tv> 1.3.7-6.mga7
+ Revision: 1154422
- fix build by not manually compressing man pages with lzma
- fix SRPM creation due to bad %%py2_install call

* Thu Aug 03 2017 philippem <philippem> 1.3.7-5.mga7
+ Revision: 1134386
- rebuild for Python 3.6

* Wed May 25 2016 daviddavid <daviddavid> 1.3.7-4.mga6
+ Revision: 1018437
- fix testsuite build against new python-coverage 4.1 adding 'test_coverage_plugin'
- use new python macros

* Fri Feb 19 2016 umeabot <umeabot> 1.3.7-3.mga6
+ Revision: 970494
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 tv <tv> 1.3.7-2.mga6
+ Revision: 886947
- disable python3 with python 3.5 like FC did
- rebuild for python 3.5

* Fri Aug 28 2015 philippem <philippem> 1.3.7-1.mga6
+ Revision: 870570
- update to 1.3.7

* Wed Oct 15 2014 umeabot <umeabot> 1.3.4-4.mga5
+ Revision: 742180
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.3.4-3.mga5
+ Revision: 729153
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 philippem <philippem> 1.3.4-1.mga5
+ Revision: 669684
- update to 1.3.4

* Sun Jun 01 2014 pterjan <pterjan> 1.3.3-1.mga5
+ Revision: 629905
- Drop no longer needed line
- 1.3.3
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.3.0-4.mga4
+ Revision: 543882
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.3.0-3.mga4
+ Revision: 498968
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 1.3.0-2.mga4
+ Revision: 471676
- Various selftests fail on our build system; skip them for now

* Mon Jul 01 2013 philippem <philippem> 1.3.0-1.mga4
+ Revision: 449480
- update to 1.3.0

* Sun Jan 13 2013 umeabot <umeabot> 1.0.0-5.mga3
+ Revision: 379162
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.0-4.mga1
+ Revision: 45344
- Rebuild against python 2.7
+ pterjan <pterjan>
- Rebuild for python 2.7

* Thu Jan 13 2011 ahmad <ahmad> 1.0.0-2.mga1
+ Revision: 8367
- drop the old %%py_requires macro and add BR python-devel
- imported package python-nose


* Thu Dec 16 2010 Lev Givon <lev@mandriva.org> 1.0.0-1mdv2011.0
+ Revision: 622412
- Update to 1.0.0.

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 0.11.4-2mdv2011.0
+ Revision: 590015
- rebuild for python 2.7

* Mon Jul 12 2010 Lev Givon <lev@mandriva.org> 0.11.4-1mdv2011.0
+ Revision: 551261
- Update to 0.11.4.

* Mon Mar 08 2010 Lev Givon <lev@mandriva.org> 0.11.3-1mdv2010.1
+ Revision: 515634
- Update to 0.11.3.

* Wed Dec 09 2009 Lev Givon <lev@mandriva.org> 0.11.1-1mdv2010.1
+ Revision: 475619
- Update to 0.11.1.

* Tue Jun 23 2009 Lev Givon <lev@mandriva.org> 0.11.0-1mdv2010.0
+ Revision: 388721
- Update to 0.11.0.

* Wed May 06 2009 Lev Givon <lev@mandriva.org> 0.10.4-3mdv2010.0
+ Revision: 372562
- Make package own its own module directory in %%py_sitedir.

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 0.10.4-2mdv2009.1
+ Revision: 319375
- rebuld for new python

* Tue Dec 16 2008 Lev Givon <lev@mandriva.org> 0.10.4-1mdv2009.1
+ Revision: 314963
- Update to 0.10.4.

* Wed Jun 18 2008 Lev Givon <lev@mandriva.org> 0.10.3-1mdv2009.0
+ Revision: 225981
- Update to 0.10.3.

* Fri May 30 2008 Lev Givon <lev@mandriva.org> 0.10.2-1mdv2009.0
+ Revision: 213479
- Update to 0.10.2.

* Tue Feb 19 2008 Lev Givon <lev@mandriva.org> 0.10.1-2mdv2008.1
+ Revision: 172897
- import python-nose


* Mon Feb 18 2008 Lev Givon <lev@mandriva.org> 0.10.1-1mdv2008.0
- Initial Mandriva package.
